==> cremerlab-utils-0.0.1.tar.gz: cremerlab-utils-0.0.1/README.md <==
# `cremerlab-utils`

This is a package holding a variety of functions used by members of the Jonas 
Cremer  Lab at Stanford University. This is very much in development and  will 
be expanded as the utilities for the lab expands 

# Installation 
While it's still in development, the package can be installed using pip from the 
command line

```
pip install cremerlab-utils
```

If you are interested in contributing to the development, it can be installed 
locally via 

```
git clone git@github.com:cremerlab/cremerlab-utils
cd cremerlab-utils
pip install -e ./
```

# License
The software is released under a standard MIT license which reads as follows:

```
MIT License

Copyright (c) 2021 The Authors

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```

==> cremerlab-utils-0.0.2.tar.gz: cremerlab-utils-0.0.2/README.md <==
# `cremerlab-utils`

This is a package holding a variety of functions used by members of the Jonas 
Cremer  Lab at Stanford University. This is very much in development and  will 
be expanded as the utilities for the lab expands 

# Installation 
If you are interested in contributing to the development, it can be installed 
locally via the [Python Package installer](https://pypi.org/project/pip/) `pip`
via the command line. 

```
$ pip install cremerlab-utils
```

If you are interested in contributing to the development of the software, 
you can clone or fork the [GitHub Repository](https://github.com/cremerlab/cremerlab-utils)
and install the package locally as follows:

```
$ git clone git@github.com:cremerlab/cremerlab-utils
$ cd cremerlab-utils
$ pip install -e ./
```

If you don't want to clone the source repository, you can install the development
version directly from GitHub:

```
$ pip install -e git+https://github.com/cremerlab/cremerlab-utils.git
```

# License
The software is released under a standard MIT license which reads as follows:

```
MIT License

Copyright (c) 2021 The Authors

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

```
